@@ -1,11 +1,9 @@
-
 try:
     # Django <= 1.3
     from django.contrib.syndication.feeds import Feed
 except ImportError:
     # Django >= 1.4
     from django.contrib.syndication.views import Feed
-from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.shortcuts import get_object_or_404
 from django.utils.feedgenerator import Atom1Feed
@@ -16,6 +14,9 @@ from mezzanine.blog.models import BlogPost, BlogCategory
 from mezzanine.generic.models import Keyword
 from mezzanine.pages.models import Page
 from mezzanine.conf import settings
+from mezzanine.utils.models import get_user_model
+
+User = get_user_model()
 
 
 class PostsRSS(Feed):
