@@ -24,31 +24,22 @@ var toggleID = function(opened, id) {
 };
 
 function showButtonWithChildren() {
-	$('li:has(li) .tree-toggle').css({visibility: 'visible'});
-	$('li:not(:has(li)) .tree-toggle').css({visibility: 'hidden'});
+    $('li:has(li) .tree-toggle').css({visibility: 'visible'});
+    $('li:not(:has(li)) .tree-toggle').css({visibility: 'hidden'});
 }
 
 $(function() {
 
-	showButtonWithChildren();
+    showButtonWithChildren();
 
     if (window.__grappelli_installed) {
         $('.delete').addClass('grappelli-delete');
     }
 
-    // There's a weird bug where the first click on a page name
-    // does nothing. If we remove the call to showButtonWithChildren
-    // it works fine, which doesn't make sense. So this click handler
-    // forces the anchors to go to their location.
-    $('#tree .changelink').click(function() {
-        location.href = $(this).attr('href');
-        return false;
-    });
-
     $('#tree .tree-toggle').click(function() {
         // Show/hide the branch and toggle the icon.
         var pageLink = $(this);
-        pageLink.parent().parent().find('ul:first').toggle();
+        pageLink.parent().parent().find('ol:first').toggle();
         pageLink.find('.icon').toggle();
         // Add or remove the page ID from the cookie.
         var opened = pageLink.find('.close:visible').length == 1;
@@ -58,14 +49,15 @@ $(function() {
     });
 
     // Show previously opened branches.
+    $('#tree ol').find('ol').hide();
     if (ids) {
-    	$('#page-' + ids.split(',').join(', #page-')).each(function(){
-			var pageLink = $(this);
-			pageLink.parent().parent().find('ul:first').toggle();
-			pageLink.find('.close').css('display', 'inline');
-			pageLink.find('.open').css('display', 'none');
-		});
-	}
+        $('#page-' + ids.split(',').join(', #page-')).each(function(){
+            var pageLink = $(this);
+            pageLink.parent().parent().find('ol:first').toggle();
+            pageLink.find('.close').css('display', 'inline');
+            pageLink.find('.open').css('display', 'none');
+        });
+    }
 
     // The dropdown list for adding a new page contains URLs for each
     // model - redirect when selected.
@@ -87,36 +79,43 @@ $(function() {
     // AJAX callback that's triggered when dragging a page to re-order
     // it has ended.
     var updateOrdering = function(event, ui) {
+        var parent = ui.item.parents('li:first');
+
         var args = {
-            'ordering_from': $(this).sortable('toArray').toString(),
-            'ordering_to': $(ui.item).parent().sortable('toArray').toString(),
+            id: ui.item[0].id,
+            parent_id: parent.length ? parent[0].id : null,
+            siblings: ui.item.parent().children().map(function(index, elem) {
+                return elem.id;
+            }).get()
         };
-        if (args['ordering_from'] != args['ordering_to']) {
-            // Branch changed - set the new parent ID.
-            args['moved_page'] = $(ui.item).attr('id');
-            args['moved_parent'] = $(ui.item).parent().parent().attr('id');
-            if (args['moved_parent'] == 'tree') {
-                delete args['moved_parent'];
-            }
-        } else {
-            delete args['ordering_to'];
-        }
+
         $.post(window.__page_ordering_url, args, function(data) {
             if (data !== "ok") {
                 alert("Error occured: " + data + "\nOrdering wasn't updated.");
             }
         });
-		showButtonWithChildren();
+
+        showButtonWithChildren();
     };
 
     // Make the pages sortable via drag and drop.
     // The `connectWith` option needs to be set separately to get
     // around a performance bug with `sortable`.
-    $('#tree ul').sortable({
-        handle: '.ordering', opacity: '.7', stop: updateOrdering,
-        forcePlaceholderSize: true, placeholder: 'placeholder',
-        revert: 150, toleranceElement: ' div'
-    }).sortable('option', 'connectWith', '#tree ul');
-    $('#tree ul').disableSelection();
+    var $tree = $('#tree > ol').nestedSortable({
+        handle: '.ordering',
+        opacity: 0.5,
+        stop: updateOrdering,
+        forcePlaceholderSize: true,
+        placeholder: 'placeholder',
+        revert: 150,
+        helper: 'clone',
+        items: 'li',
+        tabSize: 25,
+        tolerance: 'pointer',
+        toleranceElement: '> div',
+        isTree: true,
+        expandOnHover: 1000,
+        startCollapsed: true
+    });
 
 });
