@@ -10,7 +10,6 @@ from mezzanine.pages.models import Page
 from mezzanine.utils.urls import home_slug
 from mezzanine.utils.views import render
 
-
 page_processors.autodiscover()
 
 
@@ -29,9 +28,11 @@ def admin_page_ordering(request):
     if new_parent_id != page.parent_id:
         # Parent changed - set the new parent and re-order the
         # previous siblings.
-        page.parent_id = new_parent_id
-        page.save()
-        page.reset_slugs()
+        if new_parent_id is not None:
+            new_parent = Page.objects.get(id=new_parent_id)
+        else:
+            new_parent = None
+        page.set_parent(new_parent)
         pages = Page.objects.filter(parent_id=old_parent_id)
         for i, page in enumerate(pages.order_by('_order')):
             Page.objects.filter(id=page.id).update(_order=i)
