@@ -1,9 +1,12 @@
+
+from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import Model, Field
 
 from mezzanine.utils.importing import import_dotted_path
 
 
+# Backward compatibility with Django 1.5's "get_user_model".
 try:
     from django.contrib.auth import get_user_model
 except ImportError:
@@ -12,6 +15,13 @@ except ImportError:
         return User
 
 
+def get_user_model_name():
+    """
+    Returns the app_label.object_name string for the user model.
+    """
+    return getattr(settings, "AUTH_USER_MODEL", "auth.User")
+
+
 def base_concrete_model(abstract, instance):
     """
     Used in methods of abstract models to find the super-most concrete
